@@ -340,12 +340,12 @@ function myGet(name, head, bodyFoo, options)
 //    or an assoc array with name value pairs (var foo = new Array(); foo.app = 'Accounting'; foo.state = 'Ledger';)
 //  callback - the name of a function to call if the request is successful
 //  'POST'| 'GET' - use post or get for http request
-function myAjax(bodyFoo, callback, POSTGET, debug)
+function myAjax(bodyFoo, callback, POSTGET, Debug)
 {
   if (POSTGET == null) { POSTGET = 'POST'; }
   else if (POSTGET.match(/post/i) != null) { POSTGET = 'POST'; }
   if (POSTGET != 'POST') { POSTGET = 'GET'; }
-  if (debug == null) { debug = false; }
+  if (Debug == null) { Debug = false; }
   var url = "index.cgi";
   var arguments = '';
   if (typeof(bodyFoo) == "string")
@@ -374,7 +374,7 @@ function myAjax(bodyFoo, callback, POSTGET, debug)
     return false;
   }
 
-  if (debug) { alert(url); }
+  if (Debug) { alert(url+" "+arguments); }
   var http = createRequestObject();
   if (POSTGET == "POST")
   {
@@ -629,3 +629,12 @@ function recurseChildren(element, row)
     recurseChildren(childNodes[i], row);
   }
 }
+
+function debug(mytext)
+{
+  var myDiv = document.getElementById('DEBUG');
+  if (myDiv != null)
+  {
+    myDiv.innerHTML += "<div>"+mytext+"</div>";
+  }
+}
\ No newline at end of file
