@@ -343,7 +343,7 @@ function subEntityCheck(field)
 //returns true if it exists
 function subAccountCheck(field)
 {
-//  alert('sub a check');
+//debug('sub a check');
   var row = getRow(field);
   var nameCode = document.main.subAccountSwitch[document.main.subAccountSwitch.selectedIndex].value;
   var s = '';
@@ -511,6 +511,7 @@ function accountCheck(row)
 //summary:  routine checks for account existing and calls create account if needed
 function bankAccountCheck(row)
 {
+//debug('in bankAccountCheck');  
   //get account
   var field;
   eval("field = document.main.account_Display"+row+";");
@@ -1245,7 +1246,7 @@ function afterRecall(text)
     }
     document.main.journal.value = 'G';
   }
-  else //CP, CDP, CSR treats row zero as the check data.
+  else //CP, CDP, CSR, CDR treats row zero as the check data.
   {
     if (obj.journal != document.main.journal.value)
     {
@@ -1255,7 +1256,7 @@ function afterRecall(text)
     }
 
     document.main.amount_0.value = floatify(obj.rows[0].amount,2);
-    if (parseInt(document.main.id.value) > -1)
+    if (parseInt(document.main.id.value) > -1) //This is an EDIT
     {
       document.main.account_0.value = '='+obj.rows[0].account;
       var display = findIndex(ACCOUNTS['name'], obj.rows[0].account);
@@ -1265,13 +1266,25 @@ function afterRecall(text)
       }
       if (display == null) { alert(langObj['Invalid Account']); }
       document.main.account_Display0.value = display;
-      document.main.subAccount_0.value = obj.rows[0].subAccount;
+      document.main.subAccount_0.value = '='+obj.rows[0].subAccount;
       document.main.comment_0.value = obj.rows[0].comment;
       if (obj.rows[0].subEntity != '')
       {
         eval("document.main.subEntity_Display0.value = '"+ obj.rows[0].subEntity +"';");
         eval("document.main.subEntity_0.value = '="+ SUBENTITIES[obj.rows[0].subEntity] +"';");
       }
+      if (obj.rows[0].subAccount != '' && obj.rows[0].subAccount != '-1')
+      {
+        document.main.subAccount_Display0.value = obj.rows[0].subAccount;
+        if (document.main.journal.value == 'CP' || document.main.journal.value == 'CSR')
+        {
+          eval("document.main.subAccount_Display0.value = '"+ obj.rows[0].subAccount +"';");
+        }
+        else
+        {
+          eval("document.main.subAccount_Display0.value = '"+ findSubAccount(obj.rows[0].subAccount, 'name') +"';");
+        }
+      }
     }
     row++;
   }
@@ -1599,6 +1612,7 @@ function clearMe(field)
 function init()
 {
   var id = document.main.id.value;
+//debug('in init with id '+ id);
   if (ACCOUNTTYPES.length == 0)
   {
     alert(langObj['acctWarning']);
@@ -1689,6 +1703,7 @@ function init()
   }
   else
   {
+    document.main.date.focus();
     document.main.date.select();
   }
 }
@@ -1709,6 +1724,8 @@ function cancel()
 function submitData()
 {
   var amp = escape('&');
+  var pound = escape('#');
+  var view = document.main.view.value;
   document.popupForm.what.value = 'document.main.remember';
   hideDiv('mainDiv');
   showDiv('pleaseDiv');
@@ -1719,14 +1736,15 @@ function submitData()
   obj.ledgerCode = document.main.ledgerCode.value;
   obj.journal = document.main.journal.value;
   obj.payee = document.main.payeeDisplay.value.replace(/\&/g, amp);
+  obj.payee = obj.payee.replace(/#/g, pound);
   obj.date = document.main.date.value;
   obj.id = document.main.id.value;
   obj.memo = document.main.memo.value;
   if (document.main.remember.checked) { obj.remember = 1; }
 
-  var j = 0;
+  var j = 0;  //index of rows of data
   var reverse = 1;
-  for (var i = 0; i <= ROWS; i++)
+  for (var i = 0; i <= ROWS; i++)  //i is index of all rows including blank ones
   {
     if (checkRow(i))
     {
@@ -1760,15 +1778,20 @@ function submitData()
       else
       {
         var obj1 = dorcSet(i);
-//        alert(obj1.dorc+":"+obj1.amount);
         obj['amount_'+j] = obj1.amount;
-        obj['dorc_'+j] = obj1.dorc;
+        if (i == 0)
+        {
+          if (view == 'CP' || view == 'CDP') { obj['dorc_'+j] = 'false' }
+          else if (view == 'CSR' || view == 'CDR') { obj['dorc_'+j] = 'true' }
+          else { obj['dorc_'+j] = obj1.dorc; }
+        }
+        else { obj['dorc_'+j] = obj1.dorc; }
       }
       j++;
     }
   }
   obj.rows = j;
-  myAjax(obj, 'afterInsert', 'GET');
+  myAjax(obj, 'afterInsert', 'GET', false);
   INSERTING = true;
   return false;
 }
@@ -1840,14 +1863,15 @@ function postInsert(id)
 function dorcSet(row)
 {
   var obj = new Object();
+  var view = document.main.view.value;
   var meta;
   var type = accountType(row);
   eval('obj.amount = document.main.amount_'+row+'.value');
-  if (document.main.view.value == 'CP' || document.main.view.value == 'CDP')
+  if (view == 'CP' || view == 'CDP') //row 0 is a credit
   {
     if (row == 0) { floatify(obj.amount = 0.0 - obj.amount,2); }
   }
-  else if (document.main.view.value == 'CSR' || document.main.view.value == 'CDR')
+  else if (view == 'CSR' || view == 'CDR')  //row 0 is a debit. negate the others so that they will be credits
   {
     if (row > 0) { floatify(obj.amount = 0.0 - obj.amount,2); }
   }
@@ -1857,10 +1881,18 @@ function dorcSet(row)
   {
     obj.dorc = 'false';
   }
-  else
+  else if (obj.amount > 0)
   {
     obj.dorc = 'true';
   }
+  else if (row > 0 && (view == 'CP' || view == 'CDP'))  //what if amount is 0.00?  then we check view and row.
+  {
+    obj.dorc = 'true';
+  }
+  else if (row > 0 && (view == 'CSR' || view == 'CDR'))  //what if amount is 0.00?  then we check view and row.
+  {
+    obj.dorc = 'false';
+  }
 
   if (obj.amount < 0) { obj.amount  = floatify(0 - obj.amount,2); }
   return obj;
@@ -1939,6 +1971,7 @@ function convertMoneyToText(amount)
 //summary:  this routine will set the proper check/deposit number in the row given based on the Bank account from the same row
 function setCheckDepositNumber(row, CorD, force)
 {
+//debug('in setcheckDep for row '+row);
   if (force == null) { force = false; }
   var field;
   var display;
